cleanup

Function cleanup 

pub fn cleanup<T>(tag: T, engine_state: &EngineState) -> Option<T>
clean jobs if appropriate.

Drops tag and exits the current process if there are no running jobs, or if exit_warning_given is true. When running in an interactive session, warns the user if there were jobs and sets exit_warning_given instead, returning Some(tag) itself in that case. Otherwise return None