pub struct CallEval { /* private fields */ }Expand description
CallEval is used to evaluate a command or closure call.
It is intended as an internal interface in the engine, to make sure
command and closure calls behave the same.
If you want to evaluate a closure in a command, use [ClosureEval] or
[ClosureEvalOnce]. If you want to call a command, use eval_call.
CallEval has a builder API.
It is first created vial CallEval::new,
then has arguments added via CallEval::add_positional and CallEval::add_named,
and then can be run using CallEval::run.
Implementations
Sourceimpl CallEval
impl CallEval
Sourcepub fn new(
callee_stack: Stack,
call_head: Span,
callee_span: Span,
eval: EvalBlockWithEarlyReturnFn,
) -> Self
pub fn new( callee_stack: Stack, call_head: Span, callee_span: Span, eval: EvalBlockWithEarlyReturnFn, ) -> Self
Create a new CallEval context
Sourcepub fn add_positional(
&mut self,
signature: &Signature,
value: Cow<'_, Value>,
) -> Result<&mut Self, ShellError>
pub fn add_positional( &mut self, signature: &Signature, value: Cow<'_, Value>, ) -> Result<&mut Self, ShellError>
Add a positional argument to the call stack.
Returns an error if the given value does not match the type of
the argument according to the signature (see CallEval::new).
Sourcepub fn add_named(
&mut self,
signature: &Signature,
long: &str,
short: Option<String>,
value: Option<Cow<'_, Value>>,
) -> Result<&mut Self, ShellError>
pub fn add_named( &mut self, signature: &Signature, long: &str, short: Option<String>, value: Option<Cow<'_, Value>>, ) -> Result<&mut Self, ShellError>
Add a named parameter to the call stack.
Sourcepub fn with_env(
&mut self,
env_vars: &[Arc<EnvVars>],
env_hidden: &Arc<HashMap<String, HashSet<EnvName>>>,
) -> &mut Self
pub fn with_env( &mut self, env_vars: &[Arc<EnvVars>], env_hidden: &Arc<HashMap<String, HashSet<EnvName>>>, ) -> &mut Self
Sets the environment variables for the call.
Sourcepub fn debug(&mut self, debug: bool) -> &mut Self
pub fn debug(&mut self, debug: bool) -> &mut Self
Sets whether to enable debugging when evaluating the closure.
Sourcepub fn run(
&mut self,
engine_state: &EngineState,
block: &Block,
input: PipelineData,
) -> Result<PipelineData, ShellError>
pub fn run( &mut self, engine_state: &EngineState, block: &Block, input: PipelineData, ) -> Result<PipelineData, ShellError>
Run the given block.
Sourcepub fn finalize_for_signature(
&mut self,
signature: &Signature,
) -> Result<&mut Self, ShellError>
pub fn finalize_for_signature( &mut self, signature: &Signature, ) -> Result<&mut Self, ShellError>
Finalize missing/default/rest arguments without evaluating the block yet.
This is useful for callers that need to bind arguments against one signature and then evaluate a modified copy of the block without re-running the argument finalization step.
Sourcepub fn run_prebound(
&mut self,
engine_state: &EngineState,
block: &Block,
input: PipelineData,
) -> Result<PipelineData, ShellError>
pub fn run_prebound( &mut self, engine_state: &EngineState, block: &Block, input: PipelineData, ) -> Result<PipelineData, ShellError>
Run a block after arguments have already been fully bound onto the callee stack.
Sourcepub fn redirect_env(&self, engine_state: &EngineState, stack: &mut Stack)
pub fn redirect_env(&self, engine_state: &EngineState, stack: &mut Stack)
Export the modified environment from callee to the caller.