pub struct ClosureEval { /* private fields */ }Expand description
ClosureEval is used to repeatedly evaluate a closure with different values/inputs.
ClosureEval has a builder API.
It is first created via ClosureEval::new,
then has arguments added via ClosureEval::add_arg,
and then can be run using ClosureEval::run_with_input.
let mut closure = ClosureEval::new(engine_state, stack, closure);
let iter = Vec::<Value>::new()
.into_iter()
.map(move |value| closure.add_arg(value).unwrap().run_with_input(PipelineData::empty()));Many closures follow a simple, common scheme where the pipeline input and the first argument are the same value.
In this case, use ClosureEval::run_with_value:
let mut closure = ClosureEval::new(engine_state, stack, closure);
let iter = Vec::<Value>::new()
.into_iter()
.map(move |value| closure.run_with_value(value));Environment isolation and other cleanup is handled by ClosureEval,
so nothing needs to be done following ClosureEval::run_with_input or ClosureEval::run_with_value.
In contrast to ClosureEvalOnce, ClosureEval holds an owned copy of the
EngineState supplied. This makes it possible to return it from a function that
only has a borrowed EngineState reference, such as the run function of a
[nu_engine::command_prelude::Command] implementation.
Implementations
Sourceimpl ClosureEval
impl ClosureEval
Sourcepub fn new(engine_state: &EngineState, stack: &Stack, closure: Closure) -> Self
pub fn new(engine_state: &EngineState, stack: &Stack, closure: Closure) -> Self
Create a new ClosureEval.
pub fn new_preserve_out_dest( engine_state: &EngineState, stack: &Stack, closure: Closure, ) -> Self
Sourcepub fn debug(&mut self, debug: bool) -> &mut Self
pub fn debug(&mut self, debug: bool) -> &mut Self
Sets whether to enable debugging when evaluating the closure.
By default, this is controlled by the EngineState used to create this ClosureEval.
Sourcepub fn add_arg(&mut self, value: Value) -> Result<&mut Self, ShellError>
pub fn add_arg(&mut self, value: Value) -> Result<&mut Self, ShellError>
Sourcepub fn run_with_input(
&mut self,
input: PipelineData,
) -> Result<PipelineData, ShellError>
pub fn run_with_input( &mut self, input: PipelineData, ) -> Result<PipelineData, ShellError>
Run the closure, passing the given PipelineData as input.
Any arguments should be added beforehand via add_arg.
Sourcepub fn run_with_value(
&mut self,
value: Value,
) -> Result<PipelineData, ShellError>
pub fn run_with_value( &mut self, value: Value, ) -> Result<PipelineData, ShellError>
Sourcepub fn run_with_value_with_metadata(
&mut self,
value: Value,
metadata: Option<PipelineMetadata>,
) -> Result<PipelineData, ShellError>
pub fn run_with_value_with_metadata( &mut self, value: Value, metadata: Option<PipelineMetadata>, ) -> Result<PipelineData, ShellError>
Run the closure using the given Value as both the pipeline input with metadata and the first argument.
Using this function after or in combination with add_arg is most likely an error.
This function is equivalent to self.add_arg(value) followed by self.run_with_input(value.into_pipeline_data_with_metadata(metadata)).