pub struct ClosureEvalOnce<'a> { /* private fields */ }Expand description
ClosureEvalOnce is used to evaluate a closure a single time.
ClosureEvalOnce has a builder API.
It is first created via ClosureEvalOnce::new,
then has arguments added via ClosureEvalOnce::add_arg,
and then can be run using ClosureEvalOnce::run_with_input.
let result = ClosureEvalOnce::new(engine_state, stack, closure)
.add_arg(value)
.unwrap()
.run_with_input(PipelineData::empty());Many closures follow a simple, common scheme where the pipeline input and the first argument are the same value.
In this case, use ClosureEvalOnce::run_with_value:
let result = ClosureEvalOnce::new(engine_state, stack, closure).run_with_value(value);In contrast to ClosureEval, the lifetime of ClosureEvalOnce is bound
to that of the supplied EngineState reference, which makes it more light-weight.
Implementations
Sourceimpl<'a> ClosureEvalOnce<'a>
impl<'a> ClosureEvalOnce<'a>
Sourcepub fn new(
engine_state: &'a EngineState,
stack: &Stack,
closure: Closure,
) -> Self
pub fn new( engine_state: &'a EngineState, stack: &Stack, closure: Closure, ) -> Self
Create a new ClosureEvalOnce.
pub fn new_preserve_out_dest( engine_state: &'a EngineState, stack: &Stack, closure: Closure, ) -> Self
pub fn new_env_preserve_out_dest( engine_state: &'a EngineState, stack: &'a mut Stack, closure: Closure, ) -> Self
Sourcepub fn debug(self, debug: bool) -> Self
pub fn debug(self, debug: bool) -> Self
Sets whether to enable debugging when evaluating the closure.
By default, this is controlled by the EngineState used to create this ClosureEvalOnce.
Sourcepub fn add_arg(self, value: Value) -> Result<Self, ShellError>
pub fn add_arg(self, value: Value) -> Result<Self, ShellError>
Sourcepub fn add_args(self, values: Vec<Value>) -> Result<Self, ShellError>
pub fn add_args(self, values: Vec<Value>) -> Result<Self, ShellError>
Add a list of argument Values to the closure.
Sourcepub fn run_with_input(
self,
input: PipelineData,
) -> Result<PipelineData, ShellError>
pub fn run_with_input( self, input: PipelineData, ) -> Result<PipelineData, ShellError>
Run the closure, passing the given PipelineData as input.
Any arguments should be added beforehand via add_arg.
Sourcepub fn run_with_value(self, value: Value) -> Result<PipelineData, ShellError>
pub fn run_with_value(self, value: Value) -> Result<PipelineData, ShellError>
Sourcepub fn run_with_value_with_metadata(
self,
value: Value,
metadata: Option<PipelineMetadata>,
) -> Result<PipelineData, ShellError>
pub fn run_with_value_with_metadata( self, value: Value, metadata: Option<PipelineMetadata>, ) -> Result<PipelineData, ShellError>
Run the closure using the given Value as both the pipeline input with metadata and the first argument.
Using this function after or in combination with add_arg is most likely an error.
This function is equivalent to self.add_arg(value) followed by self.run_with_input(value.into_pipeline_data_with_metadata(metadata)).